Review class

Constructors

Review({String? authorName, String? authorUrl, String? language, String? originalLanguage, String? profilePhotoUrl, int? rating, String? relativeTimeDescription, String? text, int? time, bool? translated})
Review.fromJson(Map<String, dynamic> json)
factory

Properties

authorName ↔ String?
getter/setter pair
authorUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
getter/setter pair
originalLanguage ↔ String?
getter/setter pair
profilePhotoUrl ↔ String?
getter/setter pair
rating ↔ int?
getter/setter pair
relativeTimeDescription ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair
time ↔ int?
getter/setter pair
translated ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited