Prediction class

Constructors

Prediction({String? description, List<MatchedSubstring>? matchedSubstrings, String? placeId, String? reference, StructuredFormatting? structuredFormatting, List<Term>? terms, List<String>? types})
Prediction.fromJson(Map<String, dynamic> json)
factory

Properties

description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchedSubstrings ↔ List<MatchedSubstring>?
getter/setter pair
placeId ↔ String?
getter/setter pair
reference ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredFormatting ↔ StructuredFormatting?
getter/setter pair
terms ↔ List<Term>?
getter/setter pair
types ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited