MinValueInputFormatter class

Inheritance

Constructors

MinValueInputFormatter(int minValue, {String? message, bool? showToast})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
minValue → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showToast → bool?
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited