PasswordInputFormatter class

Inheritance

Constructors

PasswordInputFormatter({required bool isComplex, int? minLength, int? maxLength, String? message, bool? showToast, RegExp? regExp})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isComplex → bool
final
maxLength → int?
final
message → String?
final
minLength → int?
final
regExp → RegExp?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showToast → bool?
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited