PhoneNumberInputFormatter class

Inheritance

Constructors

PhoneNumberInputFormatter({bool mustStartWithPlus = false, int maxLength = 15, int minLength = 1, String? messagePlus, String? messageValidity, String? messageLength, bool? showToast})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxLength → int
final
messageLength → String?
final
messagePlus → String?
final
messageValidity → String?
final
minLength → int
final
mustStartWithPlus → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showToast → bool?
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited