Dates class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

initializeDateFormat({String? localization}) → Future<void>
pDateFormatter({String? localization}) → DateFormat
pDateTimeFormatter({String? localization}) → DateFormat
pDateTimeToString(DateTime? dateTime, {String? defaultValue, String? localization}) → String
pDateToString(DateTime? dateTime, {String? defaultValue, String? localization}) → String
pGetDateTimeCustomFormat(DateTime? dateTime, String format, {String? defaultValue, String? localization}) → String
pStringToDate(String date) → DateTime