Clr class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

colorPrimary ↔ Color
getter/setter pair
colorSecondary ↔ Color
getter/setter pair
colorTxt ↔ Color?
getter/setter pair
colorTxtInput ↔ Color?
getter/setter pair

Constants

colorBlack → const Color
colorCyan → const Color
colorGreen → const Color
colorGreyLight → const Color
colorTransparent → const Color
colorWhite → const Color