Btn class

Inheritance

Constructors

Btn({Key? key, required String? text, VoidCallback? onPressed, Color? textColor, Color? bgColor, Color? borderColor, double? decorationThickness, bool hasBorder = true, bool isLoose = false, bool hasBold = false, bool isTextOnly = false, double? radius, double? textSize, Widget? preFix, Widget? postFix, TextStyle? textStyle, double? verticalPadding = 4, double? borderWidth = 1, ButtonStyle? style, Color? shadowColor, Color? onSurface, double? elevation, EdgeInsetsGeometry? padding, Size? minimumSize, Size? maximumSize, Size? fixedSize, BorderSide? side, OutlinedBorder? shape, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, double? width, double? height, FontWeight? fontWeight, String? fontFamily})
const

Properties

bgColor → Color?
final
borderColor → Color?
final
borderWidth → double?
final
decorationThickness → double?
final
elevation → double?
final
fixedSize → Size?
final
fontFamily → String?
final
fontWeight → FontWeight?
final
hasBold → bool
final
hasBorder → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isLoose → bool
final
isTextOnly → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment → MainAxisAlignment
final
maximumSize → Size?
final
minimumSize → Size?
final
onPressed → VoidCallback?
final
onSurface → Color?
final
padding → EdgeInsetsGeometry?
final
postFix → Widget?
final
preFix → Widget?
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final
shape → OutlinedBorder?
final
side → BorderSide?
final
style → ButtonStyle?
final
text → String?
final
textColor → Color?
final
textSize → double?
final
textStyle → TextStyle?
final
verticalPadding → double?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildButton() → Widget
button(Widget child) → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textStyleLocal() → TextStyle
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited