BtnSF class

Inheritance

Constructors

BtnSF({Key? key, required String? text, dynamic onPressed()?, dynamic onHover(bool, dynamic (bool))?, Color? textColor, Color? bgColor, Color? foregroundColor, Color? borderColor, bool hasBorder = true, bool isLoose = false, bool hasBold = false, bool isTextOnly = false, double? radius, double? textSize, Widget? preFix, Widget? postFix, TextStyle? textStyle, double? verticalPadding = 4, double? borderWidth = 1, ButtonStyle? style, Color? shadowColor, Color? onSurface, double? elevation, EdgeInsetsGeometry? padding, Size? minimumSize, Size? maximumSize, Size? fixedSize, BorderSide? side, OutlinedBorder? shape, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, double? width, double? height, bool makeInverse = false, Widget? loadingWidget, Color? loadingColor, dynamic onPressedCallBack(dynamic (bool))?})
const

Properties

bgColor → Color?
final
borderColor → Color?
final
borderWidth → double?
final
elevation → double?
final
fixedSize → Size?
final
foregroundColor → Color?
final
hasBold → bool
final
hasBorder → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isLoose → bool
final
isTextOnly → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingColor → Color?
final
loadingWidget → Widget?
final
mainAxisAlignment → MainAxisAlignment
final
makeInverse → bool
final
maximumSize → Size?
final
minimumSize → Size?
final
onHover → dynamic Function(bool, dynamic (bool))?
final
onPressed → dynamic Function()?
final
onPressedCallBack → dynamic Function(dynamic (bool))?
final
onSurface → Color?
final
padding → EdgeInsetsGeometry?
final
postFix → Widget?
final
preFix → Widget?
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final
shape → OutlinedBorder?
final
side → BorderSide?
final
style → ButtonStyle?
final
text → String?
final
textColor → Color?
final
textSize → double?
final
textStyle → TextStyle?
final
verticalPadding → double?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BtnSF>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited