GetImage class

Inheritance

Constructors

GetImage({Key? key, String? imagePath, double width = Siz.profileImageSize, double height = Siz.profileImageSize, BoxFit fit = BoxFit.cover, double? radius, bool isAssets = false, Color? imageColor, BorderRadius? borderRadius, Color? loadingColor, GestureTapCallback? onTap, BoxDecoration? backgroundDecoration, PageController? pageController, dynamic onPageChanged(int)?, PreferredSizeWidget? appBar, Duration imageLoadingDelay = const Duration(milliseconds: 100), Color loadingBgColor = Colors.transparent, Widget? errorWidget, bool? defaultImageClick})
const

Properties

appBar → PreferredSizeWidget?
final
backgroundDecoration → BoxDecoration?
final
borderRadius → BorderRadius?
final
defaultImageClick → bool?
final
errorWidget → Widget?
final
fit → BoxFit
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
imageColor → Color?
final
imageLoadingDelay → Duration
final
imagePath → String?
final
isAssets → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBgColor → Color
final
loadingColor → Color?
final
onPageChanged → dynamic Function(int)?
final
onTap → GestureTapCallback?
final
pageController → PageController?
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildFutureBuilderImage() → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showImageInMedia(bool isAsset) → Future
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultImage ↔ String
getter/setter pair
defImageIsAsset ↔ bool
getter/setter pair