TxtFormInput<T> class

Inheritance

Constructors

TxtFormInput({Key? key, TextEditingController? controller, String? errorMessage, String? errorLengthMessage, int? maxLines, int? minLines, int? maxLength, List<TextInputFormatter>? inputFormatters, TextAlign textAlign = TextAlign.start, TextCapitalization textCapitalization = TextCapitalization.sentences, bool? isHintCapitalization, double? textSize, double? hintTextSize, Color? textColor, ValueChanged<String>? onChanged, GestureTapCallback? onTap, bool isPassword = false, TextInputType? keyboardType = TextInputType.text, TextInputAction? textInputAction, VoidCallback? onEditingComplete, FocusNode? focusNode, String? hintText = '', Color? hintTextColor, bool enabled = true, bool? hasLabel, bool? hasBorder, bool? hasLabelOnTop, bool? showLabelStar, Widget? postFix, Widget? preFix, TextStyle? postFixStyle, InputDecoration? decoration, FormFieldValidator<String>? validator, GlobalKey<FormState>? formKey, bool isOptional = false, int? validationLength, String? labelText, double? labelPadding, double? radius, BorderRadius? borderRadius, EdgeInsetsGeometry? contentPadding, Color? fillColor, Color? borderColor, double borderWidth = 2, bool autofocus = false, bool removeAllBorders = false, String? prefixText, double? prefixTextSize, double? postFixTextSize, Color? prefixTextColor, Color? postFixTextColor, double? height, TextStyle? labelStyle, TextStyle? hintStyle, TextStyle? style, TextStyle? prefixStyle, bool hasCounter = false, BorderSide? borderSide, bool? appDirectionLeftToRight, bool? showCursor, bool? readOnly, bool? ignoringWithOnTap, String? validationConditionAddOn()?, Color? cursorColor, double errorHeight = 23, bool showDropDown = false, List<DropdownMenuItem<T>>? listDropDown, T? selectedDropDownValue, dynamic onDropDownChanged(T? val)?, String? fontFamily, TextStyle? errorStyle})
const

Properties

appDirectionLeftToRight → bool?
final
autofocus → bool
final
borderColor → Color?
final
borderRadius → BorderRadius?
final
borderSide → BorderSide?
final
borderWidth → double
final
contentPadding → EdgeInsetsGeometry?
final
controller → TextEditingController?
final
cursorColor → Color?
final
decoration → InputDecoration?
final
enabled → bool
final
errorHeight → double
final
errorLengthMessage → String?
final
errorMessage → String?
final
errorStyle → TextStyle?
final
fillColor → Color?
final
focusNode → FocusNode?
final
fontFamily → String?
final
formKey → GlobalKey<FormState>?
final
hasBorder → bool?
final
hasCounter → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasLabel → bool?
final
hasLabelOnTop → bool?
final
height → double?
final
hintStyle → TextStyle?
final
hintText → String?
final
hintTextColor → Color?
final
hintTextSize → double?
final
ignoringWithOnTap → bool?
final
inputFormatters → List<TextInputFormatter>?
final
isHintCapitalization → bool?
final
isOptional → bool
final
isPassword → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
labelPadding → double?
final
labelStyle → TextStyle?
final
labelText → String?
final
listDropDown → List<DropdownMenuItem<T>>?
final
maxLength → int?
final
maxLines → int?
final
minLines → int?
final
onChanged → ValueChanged<String>?
final
onDropDownChanged → dynamic Function(T? val)?
final
onEditingComplete → VoidCallback?
final
onTap → VoidCallback?
final
postFix → Widget?
final
postFixStyle → TextStyle?
final
postFixTextColor → Color?
final
postFixTextSize → double?
final
preFix → Widget?
final
prefixStyle → TextStyle?
final
prefixText → String?
final
prefixTextColor → Color?
final
prefixTextSize → double?
final
radius → double?
final
readOnly → bool?
final
removeAllBorders → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedDropDownValue → T?
final
showCursor → bool?
final
showDropDown → bool
final
showLabelStar → bool?
final
style → TextStyle?
final
textAlign → TextAlign
final
textCapitalization → TextCapitalization
final
textColor → Color?
final
textInputAction → TextInputAction?
final
textSize → double?
final
validationConditionAddOn → String? Function()?
final
validationLength → int?
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TxtFormInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited