SearchableDropdown class

Inheritance

Constructors

SearchableDropdown({Key? key, required List<SearchListModel> list, PreferredSizeWidget? appBar, bool multiSelect = false, Icon? selectIcon, Color? selectedIconColor, String appBarText = 'Search', String searchBarHintText = 'Search', String searchBarLabelText = 'Search', bool showSearchBarLabel = true, Icon? confirmIcon, bool showBottomButton = false, String confirmButtonText = 'Select', Color? bottomButtonColor, double? bottomButtonWidth, bool? bottomButtonHasBorder, Color? bottomButtonBorderColor, bool refreshList = false})
const

Properties

appBar → PreferredSizeWidget?
final
appBarText → String
final
bottomButtonBorderColor → Color?
final
bottomButtonColor → Color?
final
bottomButtonHasBorder → bool?
final
bottomButtonWidth → double?
final
confirmButtonText → String
final
confirmIcon → Icon?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list → List<SearchListModel>
final
multiSelect → bool
final
refreshList → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchBarHintText → String
final
searchBarLabelText → String
final
selectedIconColor → Color?
final
selectIcon → Icon?
final
showBottomButton → bool
final
showSearchBarLabel → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited