ShowSnackBar class

Flutter code sample for Overlay.

Constructors

ShowSnackBar()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

overlayEntry ↔ OverlayEntry?
getter/setter pair

Static Methods

createHighlightOverlay({String? text, required BuildContext context, Color? bgColor, Color? borderColor, Color? textColor, bool hasCloseIcon = true, Widget? closeIcon, Duration? duration, double? radius, double? width, double? height, EdgeInsets? padding, EdgeInsets? margin, Alignment? alignment, dynamic onClosedTap()?, bool autoClose = true, Widget? body}) → Future<void>
removeHighlightOverlay() → void