TwoDimensionalGridView class

Inheritance

Constructors

TwoDimensionalGridView({Key? key, bool? primary, Axis mainAxis = Axis.vertical, ScrollableDetails verticalDetails = const ScrollableDetails.vertical(), ScrollableDetails horizontalDetails = const ScrollableDetails.horizontal(), required TwoDimensionalChildBuilderDelegate delegate, double width = 200, double height = 200, double? cacheExtent, DiagonalDragBehavior diagonalDragBehavior = DiagonalDragBehavior.none, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, Clip clipBehavior = Clip.hardEdge})
const

Properties

cacheExtent → double?
Deprecated. Use scrollCacheExtent instead.
finalinherited
cacheExtentStyle → CacheExtentStyle?
Deprecated. Use scrollCacheExtent instead.
finalinherited
clipBehavior → Clip
The content will be clipped (or not) according to this option.
finalinherited
delegate → TwoDimensionalChildDelegate
A delegate that provides the children for the TwoDimensionalScrollView.
finalinherited
diagonalDragBehavior → DiagonalDragBehavior
Whether scrolling gestures should lock to one axes, allow free movement in both axes, or be evaluated on a weighted scale.
finalinherited
dragStartBehavior → DragStartBehavior
Determines the way that drag start behavior is handled.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
hitTestBehavior → HitTestBehavior
Defines the behavior of gesture detector used in this Scrollable.
finalinherited
horizontalDetails → ScrollableDetails
The configuration of the horizontal Scrollable.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior?
The ScrollViewKeyboardDismissBehavior defines how this ScrollView will dismiss the keyboard automatically.
finalinherited
mainAxis → Axis
The main axis of the two.
finalinherited
primary → bool?
Whether this is the primary scroll view associated with the parent PrimaryScrollController.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollCacheExtent → ScrollCacheExtent?
The viewport has an area before and after the visible area to cache items that are about to become visible when the user scrolls.
finalinherited
verticalDetails → ScrollableDetails
The configuration of the vertical Scrollable.
finalinherited
width → double
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
buildViewport(BuildContext context, ViewportOffset verticalOffset, ViewportOffset horizontalOffset) → Widget
Build the two dimensional viewport.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited