Txt class

Inheritance

Constructors

Txt(String? text, {bool hasBold = false, bool hasItalic = false, bool hasUnderLine = false, bool hasLineThrough = false, Color? textColor, TextStyle? textStyle, double? fontSize, FontWeight? fontWeight, TextOverflow? overflow, bool checkOverFlow = false, int? maxLine, TextAlign textAlign = TextAlign.start, String? fontFamily, TextDecoration? textDecoration, bool removeHTML = false, dynamic onTap()?, double? lineHeight, TextScaler? textScaler, Key? key})
const

Properties

checkOverFlow → bool
final
fontFamily → String?
final
fontSize → double?
final
fontWeight → FontWeight?
final
hasBold → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasItalic → bool
final
hasLineThrough → bool
final
hasUnderLine → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineHeight → double?
final
maxLine → int?
final
onTap → dynamic Function()?
final
overflow → TextOverflow?
final
removeHTML → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
textAlign → TextAlign
final
textColor → Color?
final
textDecoration → TextDecoration?
final
textScaler → TextScaler?
final
textStyle → TextStyle?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited